---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2009-12-20;198
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20091231&codiceRedaz=009G0207&dataVigenza=20251104
dataGU: 20091231
codiceRedaz: 009G0207
dataVigenza: 20251104
---

# Attuazione dell'articolo 4 della legge 4 marzo 2009, n. 15, in materia di ricorso per l'efficienza delle amministrazioni e dei concessionari di servizi pubblici. (09G0207)

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 3, 24, 76, 87, 97, 103, 113 e 117, comma secondo, lettere l) ed m) della Costituzione;

Vista la legge 4 marzo 2009, n. 15, recante delega al Governo finalizzata all'ottimizzazione della produttivita' del lavoro pubblico e alla efficienza e trasparenza delle pubbliche amministrazioni nonche' disposizioni integrative delle funzioni attribuite al Consiglio nazionale dell'economia e del lavoro e alla Corte dei conti;

Visto il Regio decreto 26 giugno 1924, n. 1054, recante Testo Unico delle leggi sul Consiglio di Stato, e successive modificazioni;

Vista la legge 6 dicembre 1971, n. 1034, recante istituzione dei tribunali amministrativi regionali, e successive modificazioni;

Visto il decreto legislativo 30 luglio 1999, n. 286, recante riordino e potenziamento dei meccanismi e strumenti di monitoraggio e valutazione dei costi, dei rendimenti e dei risultati dell'attivita' svolta dalle amministrazioni pubbliche, a norma dell'articolo 11 della legge 15 marzo 1997, n. 59, e successive modificazioni;

Visto il decreto legislativo 30 marzo 2001, n. 165, recante norme generali sull'ordinamento del lavoro alle dipendenze delle amministrazioni pubbliche, e successive modificazioni;

Visto il decreto legislativo 30 giugno 2003, n. 196, recante codice in materia di protezione dei dati personali, e successive modificazioni;

Visto il decreto legislativo 7 marzo 2005, n. 82, recante codice dell'amministrazione digitale, e successive modificazioni;

Visto il decreto del Presidente del Consiglio dei Ministri 13 giugno 2008, recante delega di funzioni del Presidente del Consiglio dei Ministri in materia pubblica amministrazione e innovazione al Ministro senza portafoglio, on. prof. Renato Brunetta;

Vista la preliminare deliberazione del Consiglio dei Ministri, adottata nella riunione del 15 ottobre 2009;

Acquisita l'intesa della Conferenza Unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281 nella seduta del 12 novembre 2009;

Acquisiti i pareri delle Commissioni parlamentari competenti per materia e per i profili finanziari;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 17 dicembre 2009;

Sulla proposta del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze;

Emana il seguente decreto legislativo:

## Art. 1. - Presupposti dell'azione e legittimazione ad agire

1. Al fine di ripristinare il corretto svolgimento della funzione o la corretta erogazione di un servizio, i titolari di interessi giuridicamente rilevanti ed omogenei per una pluralita' di utenti e consumatori possono agire in giudizio, con le modalita' stabilite nel presente decreto, nei confronti delle amministrazioni pubbliche e dei concessionari di servizi pubblici, se derivi una lesione diretta, concreta ed attuale dei propri interessi, dalla violazione di termini o dalla mancata emanazione di atti amministrativi generali obbligatori e non aventi contenuto normativo da emanarsi obbligatoriamente entro e non oltre un termine fissato da una legge o da un regolamento, dalla violazione degli obblighi contenuti nelle carte di servizi ovvero dalla violazione di standard qualitativi ed economici stabiliti, per i concessionari di servizi pubblici, dalle autorita' preposte alla regolazione ed al controllo del settore e, per le pubbliche amministrazioni, definiti dalle stesse in conformita' alle disposizioni in materia di performance contenute nel decreto legislativo 27 ottobre 2009, n. 150, coerentemente con le linee guida definite dalla Commissione per la valutazione, la trasparenza e l'integrita' delle amministrazioni pubbliche di cui all'articolo 13 del medesimo decreto e secondo le scadenze temporali definite dal decreto legislativo 27 ottobre 2009, n. 150 ((, nonche' dalla mancata attuazione o violazione dei livelli di qualita' dei servizi essenziali per l'inclusione sociale e l'accessibilita' delle persone con disabilita' contenuti nelle carte dei servizi oppure degli obblighi previsti dalla normativa vigente in materia)).

1-bis. Nel giudizio di sussistenza della lesione di cui al comma 1 il giudice tiene conto delle risorse strumentali, finanziarie, e umane concretamente a disposizione delle parti intimate.

1-ter. Sono escluse dall'applicazione del presente decreto le autorita' amministrative indipendenti, gli organi giurisdizionali, le assemblee legislative e gli altri organi costituzionali nonche' la Presidenza del Consiglio dei Ministri.

2. Del ricorso e' data immediatamente notizia sul sito istituzionale dell'amministrazione o del concessionario intimati; il ricorso e' altresi' comunicato al Ministro per la pubblica amministrazione e l'innovazione.

3. I soggetti che si trovano nella medesima situazione giuridica del ricorrente possono intervenire nel termine di venti giorni liberi prima dell'udienza di discussione del ricorso che viene fissata d'ufficio, in una data compresa tra il novantesimo ed il centoventesimo giorno dal deposito del ricorso.

4. Ricorrendo i presupposti di cui al comma 1, il ricorso puo' essere proposto anche da associazioni o comitati a tutela degli interessi dei propri associati, appartenenti alla pluralita' di utenti e consumatori di cui al comma 1.

5. Il ricorso e' proposto nei confronti degli enti i cui organi sono competenti a esercitare le funzioni o a gestire i servizi cui sono riferite le violazioni e le omissioni di cui al comma 1. Gli enti intimati informano immediatamente della proposizione del ricorso il dirigente responsabile di ciascun ufficio coinvolto, il quale puo' intervenire nel giudizio. Il giudice, nella prima udienza, se ritiene che le violazioni o le omissioni sono ascrivibili ad enti ulteriori o diversi da quelli intimati, ordina l'integrazione del contraddittorio.

6. Il ricorso non consente di ottenere il risarcimento del danno cagionato dagli atti e dai comportamenti di cui al comma 1; a tal fine, restano fermi i rimedi ordinari.

7. Il ricorso e' devoluto alla giurisdizione esclusiva del giudice amministrativo e le questioni di competenza sono rilevabili anche d'ufficio.

## Art. 2. - Rapporti con le competenze di regolazione e controllo e con i giudizi instaurati ai sensi degli articoli 139, 140 e 140-bis del codice del consumo, di cui al decreto legislativo 6 settembre 2005, n. 206

1. Il ricorso di cui all'articolo 1 non puo' essere proposto se un organismo con funzione di regolazione e di controllo istituito con legge statale o regionale e preposto al settore interessato ha instaurato e non ancora definito un procedimento volto ad accertare le medesime condotte oggetto dell'azione di cui all'articolo 1, ne' se, in relazione alle medesime condotte, sia stato instaurato un giudizio ai sensi degli articoli 139, 140 e 140-bis del codice del consumo, di cui al decreto legislativo 6 settembre 2005, n. 206.

2. Nell'ipotesi in cui il procedimento di cui al comma 1 o un giudizio instaurato ai sensi degli articoli 139 e 140 del codice del consumo, di cui al decreto legislativo 6 settembre 2005, n. 206, sono iniziati dopo la proposizione del ricorso di cui all'articolo 1, il giudice di quest'ultimo ne dispone la sospensione fino alla definizione dei predetti procedimenti o giudizi. A seguito del passaggio in giudicato della sentenza che definisce nel merito il giudizio instaurato ai sensi dei citati articoli 139 e 140, il ricorso di cui all'articolo 1 diviene improcedibile. In ogni altro caso, quest'ultimo deve essere riassunto entro centoventi giorni dalla definizione del procedimento di cui al comma 1, ovvero dalla definizione con pronuncia non di merito sui giudizi instaurati ai sensi degli stessi articoli 139 e 140, altrimenti e' perento.

3. Il soggetto contro cui e' stato proposto il ricorso giurisdizionale di cui all'articolo 1 comunica immediatamente al giudice l'eventuale pendenza o la successiva instaurazione del procedimento di cui ai commi 1 e 2, ovvero di alcuno dei giudizi ivi indicati, per l'adozione dei conseguenti provvedimenti rispettivamente previsti dagli stessi commi 1 e 2.

## Art. 3. - Procedimento

1. Il ricorrente notifica preventivamente ((, anche con le modalita' di cui all'articolo 48 del decreto legislativo 7 marzo 2005, n. 82)) una diffida all'amministrazione o al concessionario ad effettuare, entro il termine di novanta giorni, gli interventi utili alla soddisfazione degli interessati. La diffida e' notificata all'organo di vertice dell'amministrazione o del concessionario, che assume senza ritardo le iniziative ritenute opportune, individua il settore in cui si e' verificata la violazione, l'omissione o il mancato adempimento di cui all'articolo 1, comma 1, e cura che il dirigente competente provveda a rimuoverne le cause. Tutte le iniziative assunte sono comunicate all'autore della diffida. Le pubbliche amministrazioni determinano, per ciascun settore di propria competenza, il procedimento da seguire a seguito di una diffida notificata ai sensi del presente comma. L'amministrazione o il concessionario destinatari della diffida, se ritengono che la violazione, l'omissione o il mancato adempimento sono imputabili altresi' ad altre amministrazioni o concessionari, invitano il privato a notificare la diffida anche a questi ultimi. ((La diffida e' altresi' comunicata dall'amministrazione pubblica o dal concessionario di servizi pubblici interessati al Ministro per la pubblica amministrazione e l'innovazione.))

2. Il ricorso e' proponibile se, decorso il termine di cui al primo periodo del comma 1, l'amministrazione o il concessionario non ha provveduto, o ha provveduto in modo parziale, ad eliminare la situazione denunciata. Il ricorso puo' essere proposto entro il termine perentorio di un anno dalla scadenza del termine di cui al primo periodo del comma 1. Il ricorrente ha l'onere di comprovare la notifica della diffida di cui al comma 1 e la scadenza del termine assegnato per provvedere, nonche' di dichiarare nel ricorso la persistenza, totale o parziale, della situazione denunciata.

3. In luogo della diffida di cui al comma 1, il ricorrente, se ne ricorrono i presupposti, puo' promuovere la risoluzione non giurisdizionale della controversia ai sensi dell'articolo 30 della legge 18 giugno 2009, n. 69; in tal caso, se non si raggiunge la conciliazione delle parti, il ricorso e' proponibile entro un anno dall'esito di tali procedure.

## Art. 4. - Sentenza

1. Il giudice accoglie la domanda se accerta la violazione, l'omissione o l'inadempimento di cui all'articolo 1, comma 1, ordinando alla pubblica amministrazione o al concessionario di porvi rimedio entro un congruo termine, nei limiti delle risorse strumentali, finanziarie ed umane gia' assegnate in via ordinaria e senza nuovi o maggiori oneri per la finanza pubblica.

2. Della sentenza che definisce il giudizio e' data notizia con le stesse modalita' previste per il ricorso dall'articolo 1, comma 2.

3. La sentenza che accoglie la domanda nei confronti di una pubblica amministrazione e' comunicata, dopo il passaggio in giudicato, agli organismi con funzione di regolazione e di controllo preposti al settore interessato, alla Commissione e all'Organismo di cui agli articoli 13 e 14 del decreto legislativo 27 ottobre 2009, n. 150, alla procura regionale della Corte dei conti per i casi in cui emergono profili di responsabilita' erariale, nonche' agli organi preposti all'avvio del giudizio disciplinare e a quelli deputati alla valutazione dei dirigenti coinvolti, per l'eventuale adozione dei provvedimenti di rispettiva competenza.

4. La sentenza che accoglie la domanda nei confronti di un concessionario di pubblici servizi e' comunicata all'amministrazione vigilante per le valutazioni di competenza in ordine all'esatto adempimento degli obblighi scaturenti dalla concessione e dalla convenzione che la disciplina.

5. L'amministrazione individua i soggetti che hanno concorso a cagionare le situazioni di cui all'articolo 1, comma 1, e adotta i conseguenti provvedimenti di propria competenza.

6. Le misure adottate in ottemperanza alla sentenza sono pubblicate sul sito istituzionale del Ministro per la pubblica amministrazione e l'innovazione e sul sito istituzionale dell'amministrazione o del concessionario soccombente in giudizio.

## Art. 5. - Ottemperanza

1. Nei casi di perdurante inottemperanza di una pubblica amministrazione si applicano le disposizioni di cui all'articolo 27, comma 1, n. 4, del regio decreto 26 giugno 1924, n. 1054.

2. La sentenza di accoglimento del ricorso di cui al comma 1 e' comunicata alla Commissione e all'Organismo di cui agli articoli 13 e 14 del decreto legislativo 27 ottobre 2009, n. 150, nonche' alla procura regionale della Corte dei conti per i casi in cui emergono profili di responsabilita' erariale.

## Art. 6. - Monitoraggio

1. La Presidenza del Consiglio dei Ministri provvede al monitoraggio dell'attuazione delle disposizioni di cui al presente decreto, anche ai fini degli eventuali interventi correttivi di cui all'articolo 2, comma 3, della legge 4 marzo 2009, n. 15.

## Art. 7. - Norma transitoria

1. In ragione della necessita' di definire in via preventiva gli obblighi contenuti nelle carte di servizi e gli standard qualitativi ed economici di cui all'articolo 1, comma 1, e di valutare l'impatto finanziario e amministrativo degli stessi nei rispettivi settori, la concreta applicazione del presente decreto alle amministrazioni ed ai concessionari di servizi pubblici e' determinata, fatto salvo quanto stabilito dal comma 2, anche progressivamente, con uno o piu' decreti del Presidente del Consiglio dei Ministri, su proposta del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze e di concerto, per quanto di competenza, con gli altri Ministri interessati.

2. In ragione della necessita' di definire in via preventiva gli obblighi contenuti nelle carte di servizi e gli standard qualitativi ed economici di cui all'articolo 1, comma 1, e di valutare l'impatto finanziario e amministrativo degli stessi nei rispettivi settori, la concreta applicazione del presente decreto alle regioni ed agli enti locali e' determinata, anche progressivamente, con uno o piu' decreti del Presidente del Consiglio dei Ministri, su proposta del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze, su conforme parere della Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281.

## Art. 8. - Invarianza finanziaria

1. Dall'attuazione del presente provvedimento non devono derivare nuovi o maggiori oneri a carico della finanza pubblica.

